@@ -30,7 +30,7 @@ require_namespaces = function(pkgs, msg = "The following packages could not be l
     if (quietly) {
       return(FALSE)
     }
-    msg = sprintf(msg, paste0(pkgs[ii], collapse = ","))
+    msg = sprintf(msg, toString(pkgs[ii]))
     stop(errorCondition(msg, packages = pkgs[ii], class = "packageNotFoundError"))
   } else if (quietly) {
     return(TRUE)
