@@ -1,5 +1,5 @@
 if (requireNamespace("testthat", quietly = TRUE)) {
-  library(testthat)
-  library(mlr3misc)
+  library("testthat")
+  library("mlr3misc")
   test_check("mlr3misc")
 }
